Documentation
¶
Overview ¶
Package mirror provides vald server interface
Index ¶
Constants ¶
const ( RPCServiceName = "Mirror" RegisterRPCName = "Register" )
Variables ¶
var File_v1_mirror_mirror_proto protoreflect.FileDescriptor
var Mirror_ServiceDesc = grpc.ServiceDesc{ ServiceName: "mirror.v1.Mirror", HandlerType: (*MirrorServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Register", Handler: _Mirror_Register_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "v1/mirror/mirror.proto", }
Mirror_ServiceDesc is the grpc.ServiceDesc for Mirror service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterMirrorServer ¶
func RegisterMirrorServer(s grpc.ServiceRegistrar, srv MirrorServer)
Types ¶
type MirrorClient ¶
type MirrorClient interface {
// Overview
// Register RPC is the method to register other Vald Mirror Gateway targets.
// ---
// Status Code
// | 0 | OK |
// | 1 | CANCELLED |
// | 3 | INVALID_ARGUMENT |
// | 4 | DEADLINE_EXCEEDED |
// | 13 | INTERNAL |
Register(ctx context.Context, in *payload.Mirror_Targets, opts ...grpc.CallOption) (*payload.Mirror_Targets, error)
}
MirrorClient is the client API for Mirror service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewMirrorClient ¶
func NewMirrorClient(cc grpc.ClientConnInterface) MirrorClient
type MirrorServer ¶
type MirrorServer interface {
// Overview
// Register RPC is the method to register other Vald Mirror Gateway targets.
// ---
// Status Code
// | 0 | OK |
// | 1 | CANCELLED |
// | 3 | INVALID_ARGUMENT |
// | 4 | DEADLINE_EXCEEDED |
// | 13 | INTERNAL |
Register(context.Context, *payload.Mirror_Targets) (*payload.Mirror_Targets, error)
// contains filtered or unexported methods
}
MirrorServer is the server API for Mirror service. All implementations must embed UnimplementedMirrorServer for forward compatibility
type UnimplementedMirrorServer ¶
type UnimplementedMirrorServer struct{}
UnimplementedMirrorServer must be embedded to have forward compatible implementations.
func (UnimplementedMirrorServer) Register ¶
func (UnimplementedMirrorServer) Register( context.Context, *payload.Mirror_Targets, ) (*payload.Mirror_Targets, error)
type UnsafeMirrorServer ¶
type UnsafeMirrorServer interface {
// contains filtered or unexported methods
}
UnsafeMirrorServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to MirrorServer will result in compilation errors.