service

package
v1.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 12, 2026 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Overview

Copyright (C) 2019-2026 vdaas.org vald team <vald@vdaas.org>

Licensed under the Apache License, Version 2.0 (the "License"); You may not use this file except in compliance with the License. You may obtain a copy of the License at

https://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Package service provides functionality for Vald.

Copyright (C) 2019-2026 vdaas.org vald team <vald@vdaas.org>

Licensed under the Apache License, Version 2.0 (the "License"); You may not use this file except in compliance with the License. You may obtain a copy of the License at

https://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Deleter

type Deleter interface {
	StartClient(ctx context.Context) (<-chan error, error)
	Start(ctx context.Context) error
}

Deleter represents an interface for deleting.

func New

func New(opts ...Option) (Deleter, error)

New returns Deleter object if no error occurs.

type Option

type Option func(_ *index) error

func WithDiscoverer

func WithDiscoverer(client discoverer.Client) Option

WithDiscoverer returns Option that sets discoverer client.

func WithIndexingConcurrency

func WithIndexingConcurrency(num int) Option

WithIndexingConcurrency returns Option that sets indexing concurrency.

func WithTargetAddrs

func WithTargetAddrs(addrs ...string) Option

WithTargetAddrs returns Option that sets indexing target addresses.

func WithTargetIndexID

func WithTargetIndexID(indexID string) Option

WithTargetIndexID returns Option that sets target deleting index ID.

Jump to